==> haskell-pandoc-lua-engine-0.2.1.4-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.2.1.4
visibility:           public
id:                   pandoc-lua-engine-0.2.1.4-5tKo27Cx8HhDLs4lBLZbKk
key:                  pandoc-lua-engine-0.2.1.4-5tKo27Cx8HhDLs4lBLZbKk
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  00f7ed1a0d3af263e5609b23215cda39
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.4-5tKo27Cx8HhDLs4lBLZbKk
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    aeson-2.1.2.1-U8Qicry0zF1f9E1tHxOto base-4.17.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-CWLl9Yo6ICTL8aCZaK2AuM
    containers-0.6.7 data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    doclayout-0.4.0.1-AHOJ6MBE3579YbRccj0b5A
    doctemplates-0.11.0.1-JSS9jKAf5dk4jlDQ6VnbYV exceptions-0.10.5
    hslua-2.3.0-JIelwCzpvSXKYa7qAgcatT
    hslua-module-doclayout-1.1.1.1-6loQYTcPErlBRewkvezkzD
    hslua-module-path-1.1.1-8lGx2qTs3Ud4AfqvdC3pAq
    hslua-module-system-1.1.2-7uvzlT6wvieInnXoOHbSC9
    hslua-module-text-1.1.0.1-54UmVDwknB2IrHK3Ok3pLK
    hslua-module-version-1.1.1-AlC6PE7huc6IKfOhmFVKQ8
    hslua-module-zip-1.1.3-Cmpmb4biitvFONxZ2Gzs7A
    hslua-repl-0.1.2-FPc2X3jAXx71F0YYpGe24S
    lpeg-1.1.0-91dcYxhcCSVp9MDssZNo mtl-2.2.2
    pandoc-3.2-8TQBRvkocdh1AEqmpSxbGe
    pandoc-lua-marshal-0.2.8-1PKWxp93bVY8gYKv4ObOyw
    pandoc-types-1.23.1-8eoy8jCfcxaA66s4z36BXR parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-engine-0.2.1.4-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.2.1.4
visibility:           public
id:                   pandoc-lua-engine-0.2.1.4-71GBC9yCX9WFXzyRLoYYKr
key:                  pandoc-lua-engine-0.2.1.4-71GBC9yCX9WFXzyRLoYYKr
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  b3264869eafaa39f469918f7e8257476
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-engine-0.2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.4-71GBC9yCX9WFXzyRLoYYKr
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl
    aeson-2.1.2.1-LvJWrHbVhNW5j5NGQeCpIT base-4.17.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.1-G4szieHg9ZoLpnVQLQvN5t
    containers-0.6.7 data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    doclayout-0.4.0.1-45Os9WjyGgTCi79F5GUlXR
    doctemplates-0.11.0.1-IrzzCmgwUhtG6iaNmX8yGe exceptions-0.10.5
    hslua-2.3.0-JbGr5LXQfWgEu875L3k0xG
    hslua-module-doclayout-1.1.1.1-5C5hbzuarUdDGx8Q7RhLqX
    hslua-module-path-1.1.1-24O24OcAhEX6WbssEWbu4b
    hslua-module-system-1.1.2-AvogJ1sbIlN8GFJLzItzUx
    hslua-module-text-1.1.0.1-D1evzZCAnxV1GE3n7NArGB
    hslua-module-version-1.1.1-AM91Ax6Iqnl79ERAJfMQUR
    hslua-module-zip-1.1.3-7PjLdRCpj8C7YtsMmaS6Nt
    hslua-repl-0.1.2-4JGn2T6HXH28iMJNvTg0UX
    lpeg-1.1.0-3AiYVi1PwavGzocuAhoZ9b mtl-2.2.2
    pandoc-3.2-DZSZkBDkixoHDnxQYNvKEj
    pandoc-lua-marshal-0.2.8-La6r4pSqHL173oVRMH1xrn
    pandoc-types-1.23.1-DjdaEWTNF5lHiiG7qu2IsH parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
